Re-exports
pub extern crate tiny_keccak as sha3;
Re-exports
pub use panic_hook::set_panic_handler;pub use crate::init::*;pub use crate::instrument::*;
Modules
Macros
Structs
- Condvar
- A Condition Variable
- Style
- A style is a collection of properties that can format a string using ANSI escape codes.
Enums
- Colour
- A colour is one specific type of ANSI escape code, and can refer to either the foreground or background colour.
- Filth
- Boolean type for clean/dirty status.
Constants
Type Aliases
- Mutex
- A mutual exclusion primitive useful for protecting shared data
- Mutex
Guard - An RAII implementation of a “scoped lock” of a mutex. When this structure is dropped (falls out of scope), the lock will be unlocked.
- RwLock
- A reader-writer lock
- RwLock
Read Guard - RAII structure used to release the shared read access of a lock when dropped.
- RwLock
Write Guard - RAII structure used to release the exclusive write access of a lock when dropped.